==> haskell-xss-sanitize-0.3.6-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.6
id: xss-sanitize-0.3.6-1IfiMxKIVrd3a9nhLVGn1L
key: xss-sanitize-0.3.6-1IfiMxKIVrd3a9nhLVGn1L
license: BSD-2-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
abi: 8c847bd56980d609bb0bbf5291ab2365
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs: /usr/lib/ghc-8.4.3/site-local/xss-sanitize-0.3.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/xss-sanitize-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/xss-sanitize-0.3.6
hs-libraries: HSxss-sanitize-0.3.6-1IfiMxKIVrd3a9nhLVGn1L
depends:
    attoparsec-0.13.2.2-LRNbjQIitwn4Jmo3hCxwCI base-4.11.1.0
    containers-0.5.11.0 css-text-0.1.3.0-JQekKZsUjdqBpxztlrMx9K
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    tagsoup-0.14.7-KTJ3O1jkqqV6ajaCVnh6SS text-1.2.3.0
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
abi-depends: attoparsec-0.13.2.2-LRNbjQIitwn4Jmo3hCxwCI=4a615f6f9c3fdb3bc12ed255f597d820
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             css-text-0.1.3.0-JQekKZsUjdqBpxztlrMx9K=2e06704e77ea9622874beca7fb8b23f6
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             tagsoup-0.14.7-KTJ3O1jkqqV6ajaCVnh6SS=e579bae461f682236de03c2c51320673
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.6-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.6
id: xss-sanitize-0.3.6-Ka9TMcAGy4vCBoO9FGJ9Kb
key: xss-sanitize-0.3.6-Ka9TMcAGy4vCBoO9FGJ9Kb
license: BSD-2-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
abi: 8bb97369f93358214923dffe0af71f18
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs: /usr/lib/ghc-8.6.1/site-local/xss-sanitize-0.3.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/xss-sanitize-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/xss-sanitize-0.3.6
hs-libraries: HSxss-sanitize-0.3.6-Ka9TMcAGy4vCBoO9FGJ9Kb
depends:
    attoparsec-0.13.2.2-FwHjzt71DhSHhjVAq259Rs base-4.12.0.0
    containers-0.6.0.1 css-text-0.1.3.0-H0IhxMuxSt5CWrIcrFTscD
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    tagsoup-0.14.7-H82R9HC8tY8BhIh7aVVhuZ text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
